---
title: 결제대행사 선택하여 연동하기
description: 각 결제대행사(PG)사별 결제 연동 방법 및 유의사항을 확인할 수 있습니다.
cover: >-
  https://images.unsplash.com/photo-1560179707-f14e90ef3623?crop=entropy&cs=srgb&fm=jpg&ixid=MnwxOTcwMjR8MHwxfHNlYXJjaHw2fHxjb21wYW55fGVufDB8fHx8MTY4MTcxNzYyNg&ixlib=rb-4.0.3&q=85
coverY: 0
targetVersions:
  - v1
versionVariants:
  v2: /opi/ko/integration/pg/v2/readme
---

## 국내결제

[나이스페이먼츠 (신모듈)](https://developers.portone.io/opi/ko/integration/pg/v1/nice-v2/readme)

[(구) 나이스페이먼츠](https://developers.portone.io/opi/ko/integration/pg/v1/nice)

[NHN KCP](https://developers.portone.io/opi/ko/integration/pg/v1/nhn-kcp)

[KG이니시스](https://developers.portone.io/opi/ko/integration/pg/v1/inicis)

[토스페이먼츠(신모듈)](https://developers.portone.io/opi/ko/integration/pg/v1/newtoss/readme)

[토스페이먼츠(구모듈)](https://developers.portone.io/opi/ko/integration/pg/v1/toss)

[스마트로(신모듈)](https://developers.portone.io/opi/ko/integration/pg/v1/smartro-v2/readme)

[스마트로(구모듈)](https://developers.portone.io/opi/ko/integration/pg/v1/smartro)

[다날](https://developers.portone.io/opi/ko/integration/pg/v1/danal)

[키움페이 (다우데이타/페이조아)](https://developers.portone.io/opi/ko/integration/pg/v1/daou/readme)

[헥토파이낸셜](https://developers.portone.io/opi/ko/integration/pg/v1/settle/readme)

[KG모빌리언스](https://developers.portone.io/opi/ko/integration/pg/v1/kg)

[KSNET](https://developers.portone.io/opi/ko/integration/pg/v1/ksnet/readme)

[이지페이(KICC)](https://developers.portone.io/opi/ko/integration/pg/v1/kicc)

[웰컴페이먼츠](https://developers.portone.io/opi/ko/integration/pg/v1/welcome/readme)

## 국내 간편결제

[네이버페이(결제형)](https://developers.portone.io/opi/ko/integration/pg/v1/naver)

[카카오페이](https://developers.portone.io/opi/ko/integration/pg/v1/kakaopay)

[페이코](https://developers.portone.io/opi/ko/integration/pg/v1/payco)

[스마일페이](https://developers.portone.io/opi/ko/integration/pg/v1/smilepay)

[토스페이(tosspay\_v2)](https://developers.portone.io/opi/ko/integration/pg/v1/tosspay-v2/readme)

[토스페이(tosspay)](https://developers.portone.io/opi/ko/integration/pg/v1/tosspay)

[토스페이먼츠 브랜드페이](https://developers.portone.io/opi/ko/integration/pg/v1/toss-brandpay/readme)

[하이픈](https://developers.portone.io/opi/ko/integration/pg/v1/hyphen)

## 해외결제

[엑심베이](https://developers.portone.io/opi/ko/integration/pg/v1/eximbay)

[페이먼트월](https://developers.portone.io/opi/ko/integration/pg/v1/paymentwall)

[페이팔(Smart Payment Buttons) 일반결제](https://developers.portone.io/opi/ko/integration/pg/v1/spb/readme)

[페이팔(Reference Transaction) 정기결제](https://developers.portone.io/opi/ko/integration/pg/v1/rt/readme)

[페이팔(Express Checkout)](https://developers.portone.io/opi/ko/integration/pg/v1/paypal)
